@@ -7,7 +7,7 @@ the imdb.IMDb function will return an instance of this class when
 called with the 'accessSystem' argument set to "http" or "web"
 or "html" (this is the default).
 
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
                2008 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
@@ -36,11 +36,12 @@ from imdb import IMDbBase
 from imdb.utils import analyze_title
 from imdb._exceptions import IMDbDataAccessError, IMDbParserError
 
-from . import characterParser, companyParser, movieParser, personParser
 from . import (
+    companyParser,
+    movieParser,
+    personParser,
     searchMovieParser,
     searchPersonParser,
-    searchCharacterParser,
     searchCompanyParser,
     searchKeywordParser
 )
@@ -274,12 +275,10 @@ class IMDbHTTPAccessSystem(IMDbBase):
         # Proxy objects.
         self.smProxy = _ModuleProxy(searchMovieParser, defaultKeys=_def)
         self.spProxy = _ModuleProxy(searchPersonParser, defaultKeys=_def)
-        self.scProxy = _ModuleProxy(searchCharacterParser, defaultKeys=_def)
         self.scompProxy = _ModuleProxy(searchCompanyParser, defaultKeys=_def)
         self.skProxy = _ModuleProxy(searchKeywordParser, defaultKeys=_def)
         self.mProxy = _ModuleProxy(movieParser, defaultKeys=_def)
         self.pProxy = _ModuleProxy(personParser, defaultKeys=_def)
-        self.cProxy = _ModuleProxy(characterParser, defaultKeys=_def)
         self.compProxy = _ModuleProxy(companyParser, defaultKeys=_def)
         self.topBottomProxy = _ModuleProxy(topBottomParser, defaultKeys=_def)
 
@@ -297,13 +296,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         except ValueError as e:
             raise IMDbParserError('invalid personID "%s": %s' % (personID, e))
 
-    def _normalize_characterID(self, characterID):
-        """Normalize the given characterID."""
-        try:
-            return '%07d' % int(characterID)
-        except ValueError as e:
-            raise IMDbParserError('invalid characterID "%s": %s' % (characterID, e))
-
     def _normalize_companyID(self, companyID):
         """Normalize the given companyID."""
         try:
@@ -323,12 +315,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         """
         return personID
 
-    def get_imdbCharacterID(self, characterID):
-        """Translate a characterID in an imdbID; in this implementation
-        the characterID _is_ the imdbID.
-        """
-        return characterID
-
     def get_imdbCompanyID(self, companyID):
         """Translate a companyID in an imdbID; in this implementation
         the companyID _is_ the imdbID.
@@ -400,7 +386,7 @@ class IMDbHTTPAccessSystem(IMDbBase):
     def _get_search_content(self, kind, ton, results):
         """Retrieve the web page for a given search.
         kind can be 'tt' (for titles), 'nm' (for names),
-        'char' (for characters) or 'co' (for companies).
+        or 'co' (for companies).
         ton is the title or the name to search.
         results is the maximum number of results to be retrieved."""
         params = 'q=%s&s=%s&mx=%s' % (quote_plus(ton, safe=''), kind, str(results))
@@ -496,14 +482,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'technical')
         return self.mProxy.tech_parser.parse(cont)
 
-    def get_movie_business(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'business')
-        return self.mProxy.business_parser.parse(cont, getRefs=self._getRefs)
-
-    def get_movie_literature(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'literature')
-        return self.mProxy.literature_parser.parse(cont)
-
     def get_movie_locations(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'locations')
         return self.mProxy.locations_parser.parse(cont)
@@ -512,10 +490,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'soundtrack')
         return self.mProxy.soundtrack_parser.parse(cont)
 
-    def get_movie_recommendations(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'recommendations')
-        return self.mProxy.rec_parser.parse(cont)
-
     def get_movie_reviews(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'reviews?count=9999999&start=0')
         return self.mProxy.reviews_parser.parse(cont)
@@ -574,12 +548,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'news')
         return self.mProxy.news_parser.parse(cont, getRefs=self._getRefs)
 
-    def get_movie_guests(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'epcast')
-        return self.mProxy.episodes_cast_parser.parse(cont)
-
-    get_movie_episodes_cast = get_movie_guests
-
     def _purge_seasons_data(self, data_d):
         if '_current_season' in data_d['data']:
             del data_d['data']['_current_season']
@@ -637,7 +605,7 @@ class IMDbHTTPAccessSystem(IMDbBase):
         return self.spProxy.search_person_parser.parse(cont, results=results)['data']
 
     def get_person_main(self, personID):
-        cont = self._retrieve(self.urls['person_main'] % personID + 'maindetails')
+        cont = self._retrieve(self.urls['person_main'] % personID)
         ret = self.pProxy.maindetails_parser.parse(cont)
         ret['info sets'] = ('main', 'filmography')
         return ret
@@ -649,10 +617,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['person_main'] % personID + 'bio')
         return self.pProxy.bio_parser.parse(cont, getRefs=self._getRefs)
 
-    def get_person_resume(self, personID):
-        cont = self._retrieve(self.urls['person_main'] % personID + 'resume')
-        return self.pProxy.resume_parser.parse(cont, getRefs=self._getRefs)
-
     def get_person_awards(self, personID):
         cont = self._retrieve(self.urls['person_main'] % personID + 'awards')
         return self.pProxy.person_awards_parser.parse(cont)
@@ -661,10 +625,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['person_main'] % personID + 'otherworks')
         return self.pProxy.otherworks_parser.parse(cont, getRefs=self._getRefs)
 
-    # def get_person_agent(self, personID):
-    #     cont = self._retrieve(self.urls['person_main'] % personID + 'agent')
-    #     return self.pProxy.agent_parser.parse(cont)
-
     def get_person_publicity(self, personID):
         cont = self._retrieve(self.urls['person_main'] % personID + 'publicity')
         return self.pProxy.publicity_parser.parse(cont)
@@ -677,10 +637,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['person_main'] % personID + 'news')
         return self.pProxy.news_parser.parse(cont)
 
-    def get_person_episodes(self, personID):
-        cont = self._retrieve(self.urls['person_main'] % personID + 'filmoseries')
-        return self.pProxy.person_series_parser.parse(cont)
-
     def get_person_genres_links(self, personID):
         cont = self._retrieve(self.urls['person_main'] % personID + 'filmogenre')
         return self.pProxy.person_genres_parser.parse(cont)
@@ -689,30 +645,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['person_main'] % personID + 'filmokey')
         return self.pProxy.person_keywords_parser.parse(cont)
 
-    def _search_character(self, name, results):
-        cont = self._get_search_content('ch', name, results)
-        return self.scProxy.search_character_parser.parse(cont, results=results)['data']
-
-    def get_character_main(self, characterID):
-        cont = self._retrieve(self.urls['character_main'] % characterID)
-        ret = self.cProxy.character_main_parser.parse(cont)
-        ret['info sets'] = ('main', 'filmography')
-        return ret
-
-    get_character_filmography = get_character_main
-
-    def get_character_biography(self, characterID):
-        cont = self._retrieve(self.urls['character_main'] % characterID + 'bio')
-        return self.cProxy.character_bio_parser.parse(cont, getRefs=self._getRefs)
-
-    def get_character_episodes(self, characterID):
-        cont = self._retrieve(self.urls['character_main'] % characterID + 'filmoseries')
-        return self.cProxy.character_series_parser.parse(cont)
-
-    def get_character_quotes(self, characterID):
-        cont = self._retrieve(self.urls['character_main'] % characterID + 'quotes')
-        return self.cProxy.character_quotes_parser.parse(cont, getRefs=self._getRefs)
-
     def _search_company(self, name, results):
         cont = self._get_search_content('co', name, results)
         url = self.urlOpener._last_url
