@@ -3,7 +3,7 @@ utils module (imdb package).
 
 This module provides basic utilities for the imdb package.
 
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
                2009 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
@@ -57,7 +57,8 @@ KIND_MAP = {
     'v': 'video movie',
     'video': 'video movie',
     'vg': 'video game',
-    'mini': 'tv mini series'
+    'mini': 'tv mini series',
+    'tv mini-series': 'tv mini series'
 }
 
 # Match only the imdbIndex (for name strings).
@@ -232,17 +233,6 @@ def canonicalTitle(title, lang=None, imdbIndex=None):
             if article[-1] == ' ':
                 title = title[:-1]
             break
-    # XXX: an attempt using a dictionary lookup.
-    # for artSeparator in (' ', "'", '-'):
-    #     article = _articlesDict.get(ltitle.split(artSeparator)[0])
-    #     if article is not None:
-    #         lart = len(article)
-    #         # check titles like "una", "I'm Mad" and "L'abbacchio".
-    #         if title[lart:] == '' or (artSeparator != ' ' and
-    #                                 title[lart:][1] != artSeparator): continue
-    #         title = '%s, %s' % (title[lart:], title[:lart])
-    #         if artSeparator == ' ': title = title[1:]
-    #         break
     return title
 
 
@@ -874,13 +864,13 @@ _re_amp = re.compile(r'&(?![^a-zA-Z0-9_#]{1,5};)')
 
 def escape4xml(value):
     """Escape some chars that can't be present in a XML value."""
-    if isinstance(value, int):
+    if isinstance(value, (int, float)):
         value = str(value)
     value = _re_amp.sub('&amp;', value)
     value = value.replace('"', '&quot;').replace("'", '&apos;')
     value = value.replace('<', '&lt;').replace('>', '&gt;')
-    if isinstance(value, str):
-        value = value.encode('ascii', 'xmlcharrefreplace')
+    if isinstance(value, bytes):
+        value = value.decode('utf-8', 'xmlcharrefreplace')
     return value
 
 
@@ -925,8 +915,6 @@ def _handleTextNotes(s):
 def _normalizeValue(value, withRefs=False, modFunct=None, titlesRefs=None,
                     namesRefs=None, charactersRefs=None):
     """Replace some chars that can't be present in a XML text."""
-    # XXX: use s.encode(encoding, 'xmlcharrefreplace') ?  Probably not
-    #      a great idea: after all, returning a unicode is safe.
     if not withRefs:
         value = _handleTextNotes(escape4xml(value))
     else:
@@ -1028,7 +1016,7 @@ def _tagAttr(key, fullpath):
         attrs['keytype'] = strType
         tagName = str(key)
     else:
-        tagName = str(bytes((key, 'ascii', 'ignore')))
+        tagName = str((key, 'ascii', 'ignore'))
     if isinstance(key, int):
         attrs['keytype'] = 'int'
     origTagName = tagName
@@ -1610,7 +1598,7 @@ def flatten(seq, toDescend=(list, dict, tuple), yieldDictKeys=False,
                                  yieldDictKeys=yieldDictKeys,
                                  onlyKeysType=onlyKeysType, scalar=scalar):
                     yield v
-        elif not isinstance(seq, (str, int, float)):
+        elif not isinstance(seq, (str, bytes, int, float)):
             for item in seq:
                 for i in flatten(item, toDescend=toDescend,
                                  yieldDictKeys=yieldDictKeys,
